@@ -8,7 +8,8 @@ using namespace Rcpp;
 
 /// Construct a Toeplitz matrix object.
 ///
-/// Instantiates a `Toeplitz` object on the C++ side, wraps it in an `Rcpp::XPtr`, and returns the corresponding `externalptr` on the R side.
+/// Instantiates a `Toeplitz` object on the C++ side, wraps it in an
+/// `Rcpp::XPtr`, and returns the corresponding `externalptr` on the R side.
 ///
 /// @param[in] N Size of Toeplitz matrix.
 /// @return An `externalptr` pointing to the Toeplitz object.
@@ -22,7 +23,7 @@ SEXP Toeplitz_ctor(int N) {
 
 /// Set the autocorrelation of the Toeplitz matrix.
 ///
-/// @param[in] pToep `externalptr` pointer to Toeplitz matrix. 
+/// @param[in] pToep `externalptr` pointer to Toeplitz matrix.
 /// @param[in] acf Autocorrelation vector of length `N`.
 ///
 // [[Rcpp::export]]
@@ -49,15 +50,16 @@ NumericVector Toeplitz_get_acf(SEXP pToep) {
 ///
 /// @param[in] pToep `externalptr` pointer to a Toeplitz matrix of size `N`.
 /// @param[in] X Matrix of size `N x p`.
-/// @return Output matrix of size `N x p` for the matrix multiplication `Y = Toeplitz(acf) * X`.
+/// @return Output matrix of size `N x p` for the matrix multiplication `Y =
+/// Toeplitz(acf) * X`.
 // [[Rcpp::export]]
 NumericMatrix Toeplitz_prod(SEXP pToep, NumericMatrix X) {
   XPtr<Toeplitz> Toep(pToep);
   int p = X.ncol();
   int N = X.nrow();
-  NumericMatrix Y(N,p);
-  for(int ii=0; ii<p; ii++) {
-    Toep->prod(&REAL(Y)[N*ii], &REAL(X)[N*ii]);
+  NumericMatrix Y(N, p);
+  for (int ii = 0; ii < p; ii++) {
+    Toep->prod(&REAL(Y)[N * ii], &REAL(X)[N * ii]);
   }
   return Y;
 }
@@ -66,15 +68,16 @@ NumericMatrix Toeplitz_prod(SEXP pToep, NumericMatrix X) {
 ///
 /// @param[in] pToep `externalptr` pointer to a Toeplitz matrix of size `N`.
 /// @param[in] X Matrix of size `N x p`.
-/// @return Output matrix of size `N x p` for the calculation of `Y = Toeplitz(acf)^{-1} * X`.
+/// @return Output matrix of size `N x p` for the calculation of `Y =
+/// Toeplitz(acf)^{-1} * X`.
 // [[Rcpp::export]]
 NumericMatrix Toeplitz_solve(SEXP pToep, NumericMatrix X) {
   XPtr<Toeplitz> Toep(pToep);
   int p = X.ncol();
   int N = X.nrow();
-  NumericMatrix Y(N,p);
-  for(int ii=0; ii<p; ii++) {
-    Toep->solve(&REAL(Y)[N*ii], &REAL(X)[N*ii]);
+  NumericMatrix Y(N, p);
+  for (int ii = 0; ii < p; ii++) {
+    Toep->solve(&REAL(Y)[N * ii], &REAL(X)[N * ii]);
   }
   return Y;
 }
@@ -91,14 +94,16 @@ double Toeplitz_log_det(SEXP pToep) {
 
 /// Gradient-specialized trace-product.
 ///
-/// Computes `trace( Tz^{-1} * Tz0 )`, where `Tz = Toeplitz(acf)` and `Tz0 = Toeplitz(acf0)`.  This trace-product appears in the computation of
+/// Computes `trace( Tz^{-1} * Tz0 )`, where `Tz = Toeplitz(acf)` and `Tz0 =
+/// Toeplitz(acf0)`.  This trace-product appears in the computation of
 /// ```
 ///  d/dx log(det(Tz)) = trace( Tz^{-1} * Toeplitz(d/dx Tz),
 /// ```
 /// i.e., where `Tz = Toeplitz(acf(x))` is a function of `x`.
 ///
 /// @param[in] pToep `externalptr` pointer to a Toeplitz matrix of size `N`.
-/// @param[in] acf0 Vector of length `N` giving the first row/column of the Toeplitz matrix `Tz0 = Toeplitz(acf0)`.
+/// @param[in] acf0 Vector of length `N` giving the first row/column of the
+/// Toeplitz matrix `Tz0 = Toeplitz(acf0)`.
 /// @return The Toeplitz trace-product `trace( Tz^{-1} * Tz0 )`.
 ///
 // [[Rcpp::export]]
@@ -109,20 +114,25 @@ double Toeplitz_trace_grad(SEXP pToep, NumericVector acf0) {
 
 /// Hessian-specialized trace-product.
 ///
-/// Computes `trace((Tz^{-1} * Tz1) * (Tz^{-1} * Tz2))`, where `Tz = Toeplitz(acf)`, `Tz1 = Toeplitz(acf1)`, and `Tz2 = Toeplitz(acf2)`.  This trace-product appears in the computation of
+/// Computes `trace((Tz^{-1} * Tz1) * (Tz^{-1} * Tz2))`, where `Tz =
+/// Toeplitz(acf)`, `Tz1 = Toeplitz(acf1)`, and `Tz2 = Toeplitz(acf2)`.  This
+/// trace-product appears in the computation of
 /// ```
-/// d^2/dxdy log(det(Tz)) = trace(Tz^{-1} d^2/dxdy Tz) - trace((Tz^{-1} d/dx Tz) * (Tz^{-1} d/dy Tz)),
+/// d^2/dxdy log(det(Tz)) = trace(Tz^{-1} d^2/dxdy Tz) - trace((Tz^{-1} d/dx Tz)
+/// * (Tz^{-1} d/dy Tz)),
 /// ```
 /// i.e., where `Tz = Toeplitz(acf(x,y))` is a function of `x` and `y`.
 ///
 /// @param[in] pToep `externalptr` pointer to a Toeplitz matrix of size `N`.
-/// @param[in] acf1 Vector of length `N` giving the first row/column of the  Toeplitz matrix `Tz1 = Toeplitz(acf1)`.
-/// @param[in] acf2 Vector of length `N` giving the first row/column of the  Toeplitz matrix `Tz2 = Toeplitz(acf2)`.
-/// @return The Toeplitz trace-product `trace((Tz^{-1} * Tz1) * (Tz^{-1} * Tz2))`.
+/// @param[in] acf1 Vector of length `N` giving the first row/column of the
+/// Toeplitz matrix `Tz1 = Toeplitz(acf1)`.
+/// @param[in] acf2 Vector of length `N` giving the first row/column of the
+/// Toeplitz matrix `Tz2 = Toeplitz(acf2)`.
+/// @return The Toeplitz trace-product `trace((Tz^{-1} * Tz1) * (Tz^{-1} *
+/// Tz2))`.
 ///
 // [[Rcpp::export]]
-double Toeplitz_trace_hess(SEXP pToep,
-			   NumericVector acf1, NumericVector acf2) {
+double Toeplitz_trace_hess(SEXP pToep, NumericVector acf1, NumericVector acf2) {
   XPtr<Toeplitz> Toep(pToep);
   return Toep->trace_hess(REAL(acf1), REAL(acf2));
 }
@@ -136,4 +146,3 @@ bool Toeplitz_has_acf(SEXP pToep) {
   XPtr<Toeplitz> Toep(pToep);
   return Toep->has_acf();
 }
-
